
#======================================================================
#
# Go thru a site and print out info on everything
#
#======================================================================

use strict;

use Data::Dumper;
use LWP::UserAgent;
use LWP::Debug;
use SOAP::Lite on_action => sub { "$_[0]$_[1]"; };
use Time::Local;


import SOAP::Data 'name', 'value';


my $lib_title   = "My Library";
my $lib_dir     = "My Library";
my $lib_dir2    = "My%20Library";

my $url         = qq(https://mysphost);
my $sp_url      = qq(sites/mysite);
my $lib_url     = $url . "/". $sp_url . "/" . $lib_dir2 . "/";
my $sp_endpoint = $url . "/". $sp_url . '/_vti_bin/lists.asmx';
my $sp_domain   = 'www.mysphost.com:443';
my $sp_username = 'mydomain\\myuserid';
my $sp_password = 'mypasswd';



#----------------------------------------------------------------------
# Debugging for SOAP and LWP
#----------------------------------------------------------------------
my $debug = 0;

if ($debug) {
    LWP::Debug::level('+');
    SOAP::Lite->import(+trace => 'all');
}




#----------------------------------------------------------------------
# SOAP
#----------------------------------------------------------------------
my @ua_args     = (keep_alive => 1);
my @credentials = ($sp_domain, "", $sp_username, $sp_password);
my $schema_ua   = LWP::UserAgent->new(@ua_args);

$schema_ua->credentials(@credentials);

my $soap = SOAP::Lite->proxy($sp_endpoint, 
                             @ua_args, 
                             credentials => \@credentials);
$soap->schema->useragent($schema_ua);
$soap->uri("http://schemas.microsoft.com/sharepoint/soap/");




#----------------------------------------------------------------------
# Get a list of all the Libraries
#----------------------------------------------------------------------
my $lists = $soap->GetListCollection();

if(defined $lists->fault) {
   print "ERROR: Could not get document library list\n";
   print $lists->faultstring; 
   print "\n\n\n";

   exit;
}

print "##### LIST = " . ref($lists) . "\n";


my @result = $lists->dataof('//GetListCollectionResult/Lists/List');

foreach my $data (@result) {
   my $attr = $data->attr;

   foreach my $a (sort keys %$attr) {
      printf "%-16s %s\n", $a, $attr->{$a};
   }

   get_doc_lib_items($soap, $attr->{ID});


   print "\n";
}



print "DONE\n\n\n";







#----------------------------------------------------------------------
# Get a list of all Items in a Library
# Look for a specific item to modify some attrs below...
#----------------------------------------------------------------------
sub get_doc_lib_items {
   my ($soap, $lib_id) = @_;

   print "\n\n\nITEMS:\n";

   
   my $call = $soap->GetListItems(SOAP::Data->name('listName' => $lib_id),
                                  SOAP::Data->name('viewName' => ''),
                                  SOAP::Data->name('rowLimit' => 99999));
   
   if(defined $call->fault) {
      print "ERROR: Could not get document library items\n";
      print $call->faultstring; 
      print "\n\n\n";
      return;
   }


   my @items = $call->dataof('//GetListItemsResult/listitems/data/row');

   foreach my $data (@items) {
      my $attr = $data->attr;
      
      foreach (sort keys %$attr) {
         printf "%-16s %s\n", $_, $attr->{$_};
      }
      
      print "\n";
   }
}











