
#======================================================================
#
# Get a single Library by Title - MyLibrary
#                      or ID    - {B6DD8E45-7E39-46B8-AE93-69360313D69A}
#
# Get a single Item in a sub folder in the Library using a Query
#
#
#======================================================================

use strict;

use Data::Dumper;
use LWP::UserAgent;
use LWP::Debug;
use SOAP::Lite on_action => sub { "$_[0]$_[1]"; };
use Time::Local;
use XML::Writer;


import SOAP::Data 'name', 'value';


my $lib_title    = "MyLibrary";
my $lib_id       = "";
my $lib_item_cnt = 0;
my $item_name    = "person1.txt";
my $item_id      = "";
my $item_ref     = "";
my $item_bh1     = "AAABBBCCCDDDEEE";
my $item_bh2     = "AAA\nBBB\nCCC";



my $url         = 'https://mysphost/';
my $sp_endpoint = $url . 'sites/demo/_vti_bin/lists.asmx';
my $sp_domain   = 'mysphost:443';
my $sp_username = 'mydomain\\myuserid';
my $sp_password = 'mypasswd';


my $debug = 1;

if ($debug) {
    LWP::Debug::level('+');
    SOAP::Lite->import(+trace => 'all');
}



#----------------------------------------------------------------------
# SOAP
#----------------------------------------------------------------------
my @ua_args     = (keep_alive => 1);
my @credentials = ($sp_domain, "", $sp_username, $sp_password);
my $schema_ua   = LWP::UserAgent->new(@ua_args);

$schema_ua->credentials(@credentials);

my $soap = SOAP::Lite->proxy($sp_endpoint, 
                             @ua_args, 
                             credentials => \@credentials);

$soap->schema->useragent($schema_ua);

$soap->uri("http://schemas.microsoft.com/sharepoint/soap/");




#----------------------------------------------------------------------
# Get a Library by Title or ID
#----------------------------------------------------------------------
my $list = $soap->GetList(SOAP::Data->name('listName' => $lib_title));
                          
quit(1, $list->faultstring()) if defined $list->fault();
                          
#print "##### LIST = " . ref($list) . "\n";
#print Dumper($list) . "\n";

my $data = $list->dataof('//GetListResult/List');
my $attr = $data->attr;
   
$lib_id       = $attr->{ID};
$lib_item_cnt = $attr->{ItemCount};
   
foreach my $a (sort keys %$attr) {
   printf "%-16s %s\n", $a, $attr->{$a};
}


print "LIB  ID = $lib_id\n";
print "ITEM ID = $item_id\n";




#----------------------------------------------------------------------
# Get the Items in a folder by Title or ID
#----------------------------------------------------------------------
# <Query>
#    <Where>
#       <Eq>
#          <FieldRef Name="LinkFilename" /> 
#          <Value Type="Text">aaa</Value> 
#       </Eq>
#    </Where>
# </Query>

# <queryOptions>
#    <QueryOptions>
#       <Folder>{Common:ListName}/foldera</Folder>
#    </QueryOptions>
# </queryOptions>

my $xml = "";
my $w = new XML::Writer(OUTPUT => \$xml);

$w->startTag("queryOptions", "xsi:type" => "xsd:string");
$w->startTag("QueryOptions");
$w->startTag("Folder");
$w->characters(qq(My Test Library/docs));
$w->endTag("Folder");
$w->endTag("QueryOptions");
$w->endTag("queryOptions");
$w->end;


print "XML = $xml\n";


my $call = $soap->GetListItems
    (SOAP::Data->name('listName' => $lib_id),
     SOAP::Data->name('viewName' => ''),
     SOAP::Data->type('xml'      => $xml),
     SOAP::Data->name('rowLimit' => 99999));

quit(1, $call->faultstring()) if defined $call->fault();

my $data = $call->dataof('//GetListItemsResult/listitems/data/row');

print "DATA = $data\n";

print Dumper($data) . "\n\n\n";

my $attr = $data->attr;

if($attr->{ows_LinkFilename} eq $item_name) {
   $item_id  = $attr->{ows_ID};
   $item_ref = $url . (split /\#/, $attr->{ows_FileRef})[1];
}


foreach (sort keys %$attr) {
   printf "%-16s %s\n", $_, $attr->{$_};
}

